%bcond_without draco
%define libnamedev %mklibname %name -d
Name:           f3d
Version:        2.4.0
Release:        %mkrel 2
Summary:        Fast and minimalist 3D viewer
License:        BSD-3-Clause
Group:          Graphics/Viewers
URL:            https://f3d.app/
Source0:        https://github.com/f3d-app/f3d/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  hdf5-devel
BuildRequires:  libstdc++-static-devel
BuildRequires:  cmake(Alembic)
BuildRequires:  cmake(Imath)
BuildRequires:  cmake(OpenCASCADE)
BuildRequires:  cmake(double-conversion)
BuildRequires:  cmake(pybind11)
BuildRequires:  cmake(utf8cpp)
BuildRequires:  cmake(vtk) >= 9.0
BuildRequires:  pkgconfig(assimp)
%if %{with draco}
BuildRequires:  pkgconfig(draco)
%endif
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(opengl)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  python3dist(pybind11)

%description
F3D is a VTK-based 3D viewer following the KISS principle, so it is
minimalist, efficient, has no GUI, has simple interaction mechanisms
and is fully controllable using arguments in the command line.

%package        python3
Summary:        Python 3 bindings for the %{name}
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
Requires:       %{name}%{?_isa} = %{version}-%{release}
Provides:       python3-%{name} = %{version}-%{release}

%description    python3
The python3-%{name} package contains Python 3 bindings for %{name}.

%package        bash-completion
Summary:        Bash completion for %{name}
Group:          Shells
Requires:       bash-completion
Supplements:    (%{name} and bash)
BuildArch:      noarch

%description    bash-completion
Bash command line completion support for %{name}.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          Shells
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description    fish-completion
Fish command line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          Shells
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description    zsh-completion
ZSH command line completion support for %{name}.

%package     -n %{libnamedev}
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
 
%description -n %{libnamedev}
This package contains development files for %{name}.

%prep
%autosetup -p1

%build
%cmake \
    -DCMAKE_SKIP_INSTALL_RPATH=ON \
    -DBUILD_TESTING=OFF \
    -DF3D_BINDINGS_JAVA=OFF \
    -DF3D_BINDINGS_PYTHON=ON \
    -Dpybind11_DIR=%{python3_sitelib}/pybind11/share/cmake/pybind11 \
    -DF3D_LINUX_APPLICATION_LINK_FILESYSTEM=ON \
    -DF3D_LINUX_GENERATE_MAN=ON \
    -DF3D_LINUX_INSTALL_DEFAULT_CONFIGURATION_FILE_IN_PREFIX=ON \
    -DF3D_MODULE_EXTERNAL_RENDERING=OFF \
    -DF3D_MODULE_RAYTRACING=OFF \
    -DF3D_PLUGINS_STATIC_BUILD=OFF \
    -DF3D_PLUGIN_BUILD_ALEMBIC=ON \
    -DF3D_PLUGIN_BUILD_ASSIMP=ON \
    -DF3D_PLUGIN_BUILD_DRACO=%{?with_draco:ON}%{?!with_draco:OFF} \
    -DF3D_PLUGIN_BUILD_EXODUS=ON \
    -DF3D_PLUGIN_BUILD_OCCT=ON
%cmake_build

%install
%cmake_install

rm -rfv %{buildroot}%{_datadir}/doc/F3D
rm -rfv %{buildroot}%{_libdir}/libvtk*.a

%files
%doc README.md
%license LICENSE.md doc/THIRD_PARTY_LICENSES.md
%{_bindir}/%{name}
%{_libdir}/lib%{name}.so.2{,.*}
%{_libdir}/lib%{name}-plugin-*.so
%{_libdir}/vtk/hierarchy/f3d_vtkext/vtkext-hierarchy.txt
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-plugin-*.desktop
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/plugins
%{_datadir}/%{name}/plugins/*.json
%{_iconsdir}/hicolor/*/apps/%{name}.??g
%{_metainfodir}/app.%{name}.F3D.metainfo.xml
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/%{name}*.thumbnailer
%{_mandir}/man1/%{name}.1.*

%files python3
%{python3_sitearch}/f3d/

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%{_datadir}/zsh/site-functions/_%{name}

%files -n %{libnamedev}	
%{_libdir}/libf3d.so
%{_libdir}/libvtkext.so
%dir %{_includedir}/f3d
%{_includedir}/f3d/*.h
%dir %{_libdir}/cmake/f3d_vtkext
%{_libdir}/cmake/f3d_vtkext/*.cmake


%changelog
* Sat May 11 2024 papoteur <papoteur> 2.4.0-2.mga10
+ Revision: 2063720
- rebuild for vtk and opencascade

* Fri Apr 05 2024 papoteur <papoteur> 2.4.0-1.mga10
+ Revision: 2054789
- new version 2.4.0
- add devel package

* Fri Mar 15 2024 papoteur <papoteur> 2.2.1-3.mga10
+ Revision: 2049980
- rebuild for draco 1.5.7
+ daviddavid <daviddavid>
- rebuild for new draco 1.5.7

* Sat Feb 17 2024 papoteur <papoteur> 2.2.1-1.mga10
+ Revision: 2042062
- new version 2.2.1
- rebuild for python 3.12

* Mon Nov 06 2023 daviddavid <daviddavid> 2.1.0-3.mga10
+ Revision: 2004728
- really enable draco plugin
- remove unwanted devel library file

* Mon Nov 06 2023 daviddavid <daviddavid> 2.1.0-2.mga10
+ Revision: 2004724
- enable now draco plugin

* Fri Sep 01 2023 papoteur <papoteur> 2.1.0-1.mga10
+ Revision: 1983191
- new 2.1.0

* Thu May 11 2023 daviddavid <daviddavid> 2.0.0-3.mga9
+ Revision: 1956578
- fix file list for armv7

* Thu May 11 2023 daviddavid <daviddavid> 2.0.0-2.mga9
+ Revision: 1956574
- use a named-versioned git tarball
- skip rpath with CMAKE_SKIP_INSTALL_RPATH macro
- do not own some data completion dir
- update Url
- add some more build dependencies

* Wed May 10 2023 papoteur <papoteur> 2.0.0-1.mga9
+ Revision: 1956523
- imported package f3d

